Upgrading from Previous Versions of Cotton2K
============================================

All input files from previous versions of COTTON2K can be used in this version.  However, in some cases it may be necessary to input or correct the year of the simulation or change the format of the dates. To do that: open the file, input the year, and then save the file. In all input files that have date strings, the user interface will automatically convert the date from the old format ("mm/dd/yy") to the new format ("dd-MON-yyyy").

Before attempting to use any input file that has been created by previous versions, just open it and then save it.
